import ColHeader from '@/components/col-header'
import { defineComponent, provide } from 'vue'
import styles from './teacher-home.module.less'
import { Popup, Tab, Tabs } from 'vant'
import Practice from './components/practice'
import Live from './components/live'
import VideoList from './components/video'
import Music from './components/music'
import request from '@/helpers/request'
import { listenerMessage } from '@/helpers/native-message'
import { useEventListener, useWindowScroll } from '@vueuse/core'
import TeacherHeader from './model/teacher-header'
import { useRect } from '@vant/use'
import { useEventTracking } from '@/helpers/hooks'
import Vip from './components/vip'
import Single from './components/single'
import JoinChat from './model/join-chat'
import FansList from './model/fans-list'
import MusicList from '@/views/music/list'
import { setLogin } from '@/state'

export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'teacherHome',
  data() {
    // 先取session中的数据，没有再取参数，默认为老师风采
    const tabs = sessionStorage.getItem('teacherHomeTabs') || ''
    const query = this.$route.query
    return {
      teacherId: query.teacherId as string,
      tabs: tabs || query.tabs || 'vip',
      userInfo: {} as any,
      background: 'rgba(55, 205, 177, 0)',
      headColor: '#fff',
      height: 'auto' as any,
      tabsHeight: 0,
      stickyHeightNum: 0,
      backIconColor: 'white',
      homeContaiterHeight: '',
      fansStatus: false,
      fansList: [],
      chatItem: {},
      chatStatus: false,
    }
  },
  async mounted() { 
    postMessage({
      api: 'setStatusBarTextColor',
      content: { statusBarTextColor: true }
    })
    this.$nextTick(() => {
      const { height } = useRect(document.querySelector('.van-tabs__wrap') as any)
      this.tabsHeight = height
      this.stickyHeight()
    })
    try {
      const userInfo = await request.get('/api-student/student/queryUserInfo')
      setLogin(userInfo.data)
    } catch {
      //
    }
    this.getTeacherDetail()
    // 监听页面返回
    listenerMessage('webViewOnResume', () => {
      this.getTeacherDetail()
    })
    useEventListener(document, 'scroll', evt => {
      const { y } = useWindowScroll()
      if (y.value > 52) {
        this.headColor = '#000'
        this.background = '#fff'
        this.backIconColor = 'black'
      } else {
        this.background = 'transparent'
        this.headColor = '#fff'
        this.backIconColor = 'white'
      }
    })
    useEventTracking('老师风采')
  },
  methods: {
    stickyHeight() {
      let height = 0
      if(this.height === 'auto') {
        height = this.tabsHeight
      } else {
        height = this.height + this.tabsHeight
      }
      this.stickyHeightNum = height;
      (this.$refs.musicListRef as any)?.updateStickyHeight(height)
    },
    async getTeacherDetail() {
      try {
        const res = await request.get('/api-student/teacher/queryTeacherHome', {
          params: {
            userId: this.teacherId
          }
        })
        this.userInfo = res.data
      } catch {}
    },
    async getFansList() {
      try {
        const res = await request.post('/api-student/imGroup/queryTeacherGroup', {
          data: {
            type: 'FAN',
            createUserId: this.teacherId
          }
        })
        this.fansList = res.data || []
      } catch {}
    },
    onItemClick(item: any) {
      this.$router.push({
        path: '/music-detail',
        query: {
          id: item.id
        }
      })
    }
  },
  render() {
    return (
      <div class={styles['teacher-record']}>
        <div ref="headers">
          <ColHeader
            hideHeader={false}
            background={this.background}
            border={false}
            color={this.headColor}
            backIconColor={this.backIconColor as any}
            onHeaderBack={() => {
              this.$nextTick(() => {
                const { height } = useRect((this as any).$refs.headers)
                this.height = Math.floor(height)
                this.stickyHeight()
              })
            }}
          />
        </div>
        <img class={styles.bgImg} src={this.userInfo.heardUrl} />
        <div class={styles.bg} style={{ paddingTop: this.height + 'px' }}></div>
        <div class={styles.teacherHeader}>
          <TeacherHeader
            userInfo={this.userInfo}
            teacherId={this.teacherId}
            onStar={(val: any) => {
              this.userInfo.isStar = val.isStar
              this.userInfo.fansNum = val.fansNum
            }}
          />

          <div class={styles.singleSection}>
            <div class={styles.btnType}>
              <div class={styles.btn1} onClick={() => {
                this.$router.push({
                  path: '/teacher-style',
                  query: {
                    teacherId: this.teacherId
                  }
                })
              }}>
                <img src={getAssetsHomeFile('icon1.png')} />
                个人风采
              </div>
              <div class={styles.btn2} onClick={async () => {
                if(this.fansList.length <= 0) {
                  await this.getFansList()
                }
                this.fansStatus = true
              }}>
                <img src={getAssetsHomeFile('icon2.png')} />
                粉丝群
              </div>
            </div>

              {this.userInfo.introduction && <div class={styles.singleContent}>
              {this.userInfo.introduction}
            </div>}
            
          </div>
        </div>
        <Tabs
          color="var(--van-primary)"
          background="#f8f9fc"
          shrink
          lineWidth={44}
          sticky
          offsetTop={this.height}
          v-model:active={this.tabs}
          onChange={() => {
            sessionStorage.setItem('teacherHomeTabs', this.tabs as string)
          }}
        >
          {/* <Tab title="个人风采" name="single">
            <div style={{ minHeight: this.homeContaiterHeight }}>
              {this.tabs === 'single' && <Single userInfo={this.userInfo} />}
            </div>
          </Tab> */}
          <Tab title="VIP定制课" name="vip">
            <div style={{ minHeight: this.homeContaiterHeight }}>
              {this.tabs === 'vip' && (
                <Vip userInfo={this.userInfo} />
              )}
            </div>
          </Tab>
          <Tab title="趣纠课" name="practice">
            <div style={{ minHeight: this.homeContaiterHeight }}>
              {this.tabs === 'practice' && (
                <Practice userInfo={this.userInfo} />
              )}
            </div>
          </Tab>
          <Tab title="直播课" name="live">
            <div style={{ minHeight: this.homeContaiterHeight }}>
              {this.tabs === 'live' && <Live />}
            </div>
          </Tab>
          <Tab title="视频课" name="video">
              {this.tabs === 'video' && <VideoList />}
          </Tab>
          <Tab title="乐谱" name="music">
            {this.tabs === 'music' && <MusicList
                hideSearch
                onlySearch
                myself
                height={this.stickyHeightNum}
                ref="musicListRef"
                onItemClick={this.onItemClick}
                teacherId={this.teacherId}
              />
            }
          </Tab>
        </Tabs>

        <Popup show={this.fansStatus} class={styles.fansPopup} closeable onClose={() => this.fansStatus = false}>
          <FansList fansList={this.fansList} onConfirm={(item: any) => {
            this.chatStatus = true
            this.chatItem = item
          }} />
        </Popup>

        <Popup
          show={this.chatStatus}
          position="bottom"
          round
          closeable
          safe-area-inset-bottom
          onClose={() => (this.chatStatus = false)}
        >
          <JoinChat
            item={this.chatItem}
            onClose={(id: number) => {
              this.fansList.forEach((item: any) => {
                item.id === id && (item.hasWaitAuditFlag = true)
              })
              this.chatStatus = false
            }}
          />
        </Popup>
      </div>
    )
  }
})
